@@ -1,6 +1,6 @@
 ;; user options shared by Ada mode indentation engines  -*- lexical-binding:t -*-
 ;;
-;; Copyright (C) 2012, 2013, 2015, 2017  Free Software Foundation, Inc.
+;; Copyright (C) 2012, 2013, 2015, 2017 - 2019  Free Software Foundation, Inc.
 ;;
 ;; Author: Stephen Leake <stephen_leake@member.fsf.org>
 ;; Contributors: Simon Wright <simon.j.wright@mac.com>
@@ -39,18 +39,7 @@ begin
   :safe #'integerp)
 (make-variable-buffer-local 'ada-indent)
 
-(defvar ada-broken-indent nil)
-(make-obsolete-variable
- 'ada-broken-indent
- 'ada-indent-broken
- "Emacs 24.4, Ada mode 5.0")
-
-(defcustom ada-indent-broken
-  (if ada-broken-indent
-      (progn
-	(message "WARNING: setting `ada-indent-broken' to obsolete `ada-broken-indent'")
-	ada-broken-indent)
-    2)
+(defcustom ada-indent-broken 2
   "Indentation for the continuation of a broken line.
 
 Example :
@@ -77,26 +66,10 @@ That is, one of:
 
 Otherwise, they are indented as a with previous comments or code."
   :type  'boolean
-  :group 'ada-indentation
   :safe  #'booleanp)
 (make-variable-buffer-local 'ada-indent-comment-gnat)
 
-(defvar ada-label-indent nil)
-(make-obsolete-variable
- 'ada-label-indent
- 'ada-indent-label
- "Emacs 24.4, Ada mode 5.0")
-
-(defcustom ada-indent-label
-    (if ada-label-indent
-      (progn
-	(message "WARNING: setting `ada-indent-label' to obsolete `ada-label-indent'")
-	ada-label-indent)
-      -3)
-  ;; Ada mode 4.01 and earlier default this to -4. But that is
-  ;; incompatible with the default gnat indentation style check, which
-  ;; wants all indentations to be a multiple of 3 (with some
-  ;; exceptions). So we default this to -3.
+(defcustom ada-indent-label -3
   "Indentation for a loop, block, or statement label, relative to the item it labels.
 
 Example :
@@ -110,7 +83,7 @@ Example :
 (make-variable-buffer-local 'ada-indent-label)
 
 (defcustom ada-indent-record-rel-type 3
-  "Indentation for `record' relative to `type' or `use'.
+  "Indentation for line containing `record' relative to `type' or `for'.
 
 An example is:
    type A is
@@ -120,20 +93,19 @@ An example is:
 (make-variable-buffer-local 'ada-indent-record-rel-type)
 
 (defcustom ada-indent-renames 2
-  "Indentation for `renames' relative to the matching subprogram keyword.
+  "Indentation for `renames' relative to the subprogram keyword.
 
 For `renames' of non-subprograms the indentation is
-`ada-indent-broken' relative to the line containing the matching
-keyword.
+`ada-indent-broken' relative to the start of the statement.
 
 If the subprogram has parameters then if `ada-indent-renames' is
 zero or less the indentation is abs `ada-indent-renames' relative
 to the open parenthesis; if `ada-indent-renames' is one or more
-the indentation is relative to the line containing the keyword.
+the indentation is relative to the line containing the subprogram
+keyword ('function' or 'procedure').
 
 If the subprogram has no parameters then the indentation is
-`ada-indent-broken' relative to the indentation of the line
-containing the keyword.
+`ada-indent-broken' relative to the line containing the keyword.
 
 Examples:
    ada-indent-renames = 2
@@ -152,7 +124,7 @@ Examples:
   "Indentation for `return' relative to the matching `function' keyword.
 
 If the function has parameters, then if `ada-indent-return' is
-zero or less the indentation is abs `ada-indent-return' relative
+zero or less, the indentation is abs `ada-indent-return' relative
 to the open parenthesis; if `ada-indent-return' is one or more,
 indentation is relative to line containing `function'.
 
@@ -166,18 +138,7 @@ An example is:
   :safe #'integerp)
 (make-variable-buffer-local 'ada-indent-return)
 
-(defvar ada-use-indent nil)
-(make-obsolete-variable
- 'ada-use-indent
- 'ada-indent-use
- "Emacs 24.4, Ada mode 5.0")
-
-(defcustom ada-indent-use
-    (if ada-use-indent
-      (progn
-	(message "WARNING: setting `ada-indent-use' to obsolete `ada-use-indent'")
-	ada-use-indent)
-      ada-indent-broken)
+(defcustom ada-indent-use ada-indent-broken
   "Indentation for the lines in a `use' statement.
 
 An example is:
@@ -187,18 +148,7 @@ An example is:
   :safe #'integerp)
 (make-variable-buffer-local 'ada-indent-use)
 
-(defvar ada-when-indent nil)
-(make-obsolete-variable
- 'ada-when-indent
- 'ada-indent-when
- "Emacs 24.4, Ada mode 5.0")
-
-(defcustom ada-indent-when
-    (if ada-when-indent
-      (progn
-	(message "WARNING: setting `ada-indent-when' to obsolete `ada-when-indent'")
-	ada-when-indent)
-      3)
+(defcustom ada-indent-when 3
   "Indentation for `when' relative to `exception', `case', `or' in select.
 
 An example is:
@@ -208,18 +158,7 @@ An example is:
   :safe  #'integerp)
 (make-variable-buffer-local 'ada-indent-when)
 
-(defvar ada-with-indent nil)
-(make-obsolete-variable
- 'ada-with-indent
- 'ada-indent-with
- "Emacs 24.4, Ada mode 5.0")
-
-(defcustom ada-indent-with
-    (if ada-with-indent
-      (progn
-	(message "WARNING: setting `ada-indent-with' to obsolete `ada-with-indent'")
-	ada-with-indent)
-      ada-indent-broken)
+(defcustom ada-indent-with ada-indent-broken
   "Indentation for the lines in a `with' context clause.
 
 An example is:
@@ -230,8 +169,25 @@ An example is:
 (make-variable-buffer-local 'ada-indent-with)
 
 (defcustom ada-indent-hanging-rel-exp nil
-  "If non-nil, indent hanging lines relative to start of expression.
-Otherwise, indent relative to previous line."
+  "If nil, indent hanging lines in an expression relative to the first line.
+Otherwise, indent by `ada-indent-broken' relative to the start of the expression."
+  :type 'boolean
+  :safe #'booleanp)
+(make-variable-buffer-local 'ada-indent-hanging-rel-exp)
+
+(defcustom ada-indent-after-trailing-comment t
+ "If t, align comment lines imediately following a comment on the
+ same line as code with the preceding comment. Otherwise, ignore
+ the preceding comment."
+  :type 'boolean
+  :safe #'booleanp)
+(make-variable-buffer-local 'ada-indent-after-trailing-comment)
+
+(defcustom ada-end-name-optional nil
+  "If t, names at ends of blocks/subprograms are optional (as in
+standard Ada). If nil, they are required; this helps in error
+recovery, and matches the gnat style option -gnatye.
+Default is nil because it significantly improves error recovery."
   :type 'boolean
   :safe #'booleanp)
 (make-variable-buffer-local 'ada-indent-hanging-rel-exp)
